import"./outputWidgets.723dbd35.js";import"./index.c827a0f6.js";import{M as n}from"./Title.ad9727d9.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ab113531-2c94-4df1-9178-5ca1a17093d8",t._sentryDebugIdIdentifier="sentry-dbid-ab113531-2c94-4df1-9178-5ca1a17093d8")}catch{}})();function a(t){switch(typeof t){case"object":return Object.entries(t).map(([e,r])=>({title:e,key:e,children:a(r)}));default:return[{title:t,key:t}]}}function i(t,e){return new Promise(r=>{n.confirm({title:t,onOk:()=>r(!0),okText:e==null?void 0:e.okText,onCancel:()=>r(!1),cancelText:e==null?void 0:e.cancelText})})}export{i as a,a as t};
//# sourceMappingURL=ant-design.64772334.js.map
