import{d as u,eA as b,G as f,b as y,c as g,u as _}from"./outputWidgets.723dbd35.js";import{a as w}from"./asyncComputed.6087fd05.js";import"./router.c09623bf.js";import"./index.f80aedcf.js";import{M as n}from"./member.21ceaf3b.js";import{C as I}from"./CrudView.ca2cf6ee.js";import"./Form.71a7af16.js";import"./index.b41dfd0a.js";import"./record.c3c42720.js";import"./pubsub.97441533.js";import"./gateway.ed2ccaa3.js";import"./icons.d199659e.js";import"./index.d0473694.js";import"./Title.ad9727d9.js";import"./url.c8598ea1.js";import"./index.4913d787.js";import"./index.f91ebf4c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="7cab4052-9108-4479-9c62-0fdd84937e18",e._sentryDebugIdIdentifier="sentry-dbid-7cab4052-9108-4479-9c62-0fdd84937e18")}catch{}})();const j=u({__name:"Members",setup(e){const r=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),c()},{loading:l,result:d,refetch:c}=w(()=>n.list(r)),p=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{j as default};
//# sourceMappingURL=Members.4c55bd22.js.map
