import{d,eA as b,G as l,a as f,b as g,c as v,w as r,f as s}from"./outputWidgets.723dbd35.js";import{B as h}from"./BaseLayout.d2f45695.js";import{a as _}from"./asyncComputed.6087fd05.js";import"./router.c09623bf.js";import"./index.f80aedcf.js";import{P as y}from"./project.47055dba.js";import{O as z}from"./organization.97807207.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.49d86591.js";import{S as I}from"./Sidebar.6adcf1c3.js";import{y as w,z as k,A as B,B as C,C as P,D as $,q as x,E as D,F as L,u as M,v as O,x as S}from"./icons.d199659e.js";import"./Form.71a7af16.js";import"./index.b41dfd0a.js";import"./record.c3c42720.js";import"./pubsub.97441533.js";import"./gateway.ed2ccaa3.js";import"./logo.084e5d7c.js";import"./index.1d13fc65.js";import"./Title.ad9727d9.js";import"./index.d0473694.js";import"./Tooltip.0d7dc585.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="b06f7864-eff2-4184-acd5-836e62cf0e1c",o._sentryDebugIdIdentifier="sentry-dbid-b06f7864-eff2-4184-acd5-836e62cf0e1c")}catch{}})();const oa=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=_(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),m=l(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=l(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:k},{name:"Connectors",path:"connectors",icon:B},{name:"Tables",path:"tables",icon:C},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Files",path:"files",icon:x},{name:"Logs",icon:D,path:"logs",beta:!0},{name:"Settings",icon:L,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:O,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:S,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=f("router-view");return g(),v(h,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{oa as default};
//# sourceMappingURL=Project.ef4a521a.js.map
