import{t,b as s,eu as a}from"./outputWidgets.723dbd35.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4008e99f-81a3-471a-9eac-b99f72050f0f",e._sentryDebugIdIdentifier="sentry-dbid-4008e99f-81a3-471a-9eac-b99f72050f0f")}catch{}})();const o={},r={class:"organization-settings"};function f(e,n){return s(),a("div",r,"Organization settings")}const d=t(o,[["render",f]]);export{d as default};
//# sourceMappingURL=OrganizationSettings.73965214.js.map
