import"./outputWidgets.723dbd35.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="aa2671db-cff8-492c-957c-25e630b3da7c",e._sentryDebugIdIdentifier="sentry-dbid-aa2671db-cff8-492c-957c-25e630b3da7c")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.c8598ea1.js.map
