.sidebar-preview[data-v-b63130ce]{padding:15px}.sidebar-preview .sidebar-frame[data-v-b63130ce]{position:relative;box-shadow:0 15px 15px #0000001a}.sidebar-preview .widgets[data-v-b63130ce]{height:500px;overflow:auto}.sidebar-preview .widgets .dash[data-v-b63130ce]{display:flex;flex-direction:column;gap:20px}
