import{d as u,G as _,b as l,eu as r,e as p,b6 as m,eB as y,ey as b,eC as f,ew as g,t as k,r as v,o as I,c as w,w as i,f as h,az as B,eR as C,u as d,bX as N,eX as S}from"./outputWidgets.723dbd35.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5c9c1f56-ec69-461a-b4b2-c86707b0d8bc",e._sentryDebugIdIdentifier="sentry-dbid-5c9c1f56-ec69-461a-b4b2-c86707b0d8bc")}catch{}})();const D={key:0,class:"p-steps p-component"},x={class:"p-steps-list"},V={class:"p-menuitem-link"},E={class:"p-steps-number"},$=u({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const t=e,a=_(()=>t.stepsInfo?Array(t.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(o,c)=>e.stepsInfo?(l(),r("nav",D,[p("ol",x,[(l(!0),r(m,null,y(a.value,(s,n)=>(l(),r("li",{key:n,class:b(["p-steps-item",{"p-highlight":n+1===e.stepsInfo.current}])},[p("span",V,[p("span",E,f(n+1),1)])],2))),128))])])):g("",!0)}});const A=k($,[["__scopeId","data-v-c6d9488a"]]),K=u({__name:"ActionButton",props:{action:{},displayName:{},loading:{type:Boolean}},emits:["click"],setup(e,{emit:t}){const a=e,o=v(null);return I(()=>{o.value&&a.action.setElement(o.value)}),(c,s)=>(l(),w(d(S),null,{default:i(()=>[h(d(N),{ref_key:"element",ref:o,class:"next-button",loading:c.loading,onClick:s[0]||(s[0]=n=>t("click")),onKeydown:s[1]||(s[1]=C(n=>t("click"),["enter"]))},{default:i(()=>[B(f(c.displayName),1)]),_:1},8,["loading"])]),_:1}))}});export{A as S,K as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.b7e285dc.js.map
