import{d as y,r as i,G as b,b as x,eu as g,de as v,e as p,eC as m,ev as w,t as B}from"./outputWidgets.723dbd35.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="61d46937-1062-44cb-865b-b37476b97dd3",t._sentryDebugIdIdentifier="sentry-dbid-61d46937-1062-44cb-865b-b37476b97dd3")}catch{}})();const D={class:"text"},k=y({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(t){const e=t,s=i(Date.now()),c=()=>{s.value=Date.now()},n=i(null),u=()=>{var l,a,d;const o=(l=n.value)==null?void 0:l.getBoundingClientRect();if(!o)return{};const{x:r,y:_}=o;return s.value,{position:"fixed",top:`${_+((a=e.top)!=null?a:0)}px`,left:`${r+((d=e.left)!=null?d:0)}px`}},f=b(()=>{var o;return e.fixed?u():{left:`${(o=e.left)!=null?o:-14}px`,...e.top?{top:`${e.top}px`}:{}}});return(o,r)=>(x(),g("div",{ref_key:"tooltipBox",ref:n,class:"tooltip-box",onMouseenter:c},[v(o.$slots,"default",{},void 0,!0),p("div",{class:"tooltip",style:w(f.value)},[p("span",D,m(t.text),1)],4)],544))}});const h=B(k,[["__scopeId","data-v-74636348"]]);export{h as T};
//# sourceMappingURL=Tooltip.0d7dc585.js.map
