import{S as p}from"./Sidebar.6adcf1c3.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.49d86591.js";import{u as d,v as l,x as u}from"./icons.d199659e.js";import{d as b,eA as f,G as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.723dbd35.js";import{a as w}from"./asyncComputed.6087fd05.js";import"./router.c09623bf.js";import"./index.f80aedcf.js";import{O as z}from"./organization.97807207.js";import{B as h}from"./BaseLayout.d2f45695.js";import"./Tooltip.0d7dc585.js";import"./logo.084e5d7c.js";import"./index.1d13fc65.js";import"./Title.ad9727d9.js";import"./index.d0473694.js";import"./Form.71a7af16.js";import"./index.b41dfd0a.js";import"./record.c3c42720.js";import"./pubsub.97441533.js";import"./gateway.ed2ccaa3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0ac1ed49-e5d0-4a97-8961-0d8e69ecee47",e._sentryDebugIdIdentifier="sentry-dbid-0ac1ed49-e5d0-4a97-8961-0d8e69ecee47")}catch{}})();const H=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{H as default};
//# sourceMappingURL=Organization.c2627724.js.map
