import{d as k,eA as B,ez as I,G as w,a as h,b as o,c as d,w as a,eI as z,f as n,u as e,eu as c,eB as j,az as g,eC as x,b6 as C,ew as A,bx as D,cG as S}from"./outputWidgets.723dbd35.js";import{B as $}from"./BaseLayout.d2f45695.js";import{a as M}from"./asyncComputed.6087fd05.js";import{_ as N}from"./component.vue_vue_type_script_setup_true_lang.d69018f1.js";import"./router.c09623bf.js";import{a as P}from"./build.56bbaa22.js";import"./index.f80aedcf.js";import{P as R}from"./project.47055dba.js";import{O as V}from"./organization.97807207.js";import{B as E,a as G,c as L}from"./index.1d13fc65.js";import{c as O}from"./index.d0473694.js";import"./gateway.ed2ccaa3.js";import"./Log.4771587d.js";import"./ant-design.64772334.js";import"./index.c827a0f6.js";import"./Title.ad9727d9.js";import"./index.f6f74d5b.js";import"./WarningFilled.d99917ef.js";import"./index.b41dfd0a.js";import"./index.739d097b.js";import"./TabPane.706e80e5.js";import"./Form.71a7af16.js";import"./icons.d199659e.js";import"./index.4d6b52da.js";import"./record.c3c42720.js";import"./pubsub.97441533.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[s]="54002e20-390f-40c4-a903-eeea0bb7aca5",i._sentryDebugIdIdentifier="sentry-dbid-54002e20-390f-40c4-a903-eeea0bb7aca5")}catch{}})();const T={key:0},F={key:2},_e=k({__name:"Build",setup(i){const s=B(),p=I(),m=s.params.buildId,{result:t,loading:b}=M(async()=>{const r=await P.get(m),u=await R.get(r.projectId),l=await V.get(u.organizationId);return z({bs:r,project:u,organization:l})}),f=w(()=>!b.value&&t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.organization.name,path:`/organizations/${t.value.organization.id}`},{label:`Build ${m.split("-")[0]}`,path:`/projects/${t.value.project.id}/builds`}]:void 0);function y(){var r;(r=t.value)!=null&&r.project.id&&p.push({name:"builds",params:{projectId:t.value.project.id}})}return(r,u)=>{const l=h("router-link");return o(),d($,null,{navbar:a(()=>[n(e(L),{title:"Inspect Build",style:{padding:"5px 10px"},onBack:y},{breadcrumb:a(()=>[f.value?(o(),d(e(E),{key:0},{default:a(()=>[(o(!0),c(C,null,j(f.value,(_,v)=>(o(),d(e(G),{key:v},{default:a(()=>[n(l,{to:_.path},{default:a(()=>[g(x(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):A("",!0)]),_:1})]),content:a(()=>[e(b)?(o(),c("div",T,[n(e(D))])):e(t)?(o(),d(N,{key:1,"build-spec":e(t).bs},null,8,["build-spec"])):(o(),c("div",F,[n(e(S),{direction:"vertical"},{default:a(()=>[n(e(O),null,{default:a(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{_e as default};
//# sourceMappingURL=Build.2f40983c.js.map
