import{U as c}from"./outputWidgets.723dbd35.js";import{c as i,d}from"./index.f00da085.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="51070fa4-4b02-480f-830d-429d0c5470e9",e._sentryDebugIdIdentifier="sentry-dbid-51070fa4-4b02-480f-830d-429d0c5470e9")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:a}=i(d),b=c(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{b as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.345ff931.js.map
