import{cA as r}from"./outputWidgets.723dbd35.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="ec86461a-fb03-4030-a86f-ff234fc7b0da",e._sentryDebugIdIdentifier="sentry-dbid-ec86461a-fb03-4030-a86f-ff234fc7b0da")}catch{}})();const t=(e,f)=>{r.error({message:e,description:f})};export{t as p};
//# sourceMappingURL=popupNotifcation.d59196e1.js.map
